<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Modules\Cadastros\Services\FornecedoresParaComprasExtrasService;
use Teknisa\GER\Services\CryptService;

class FornecedoresParaComprasExtrasController extends \Zeedhi\Framework\Controller\Report
{
    protected $connection;
    protected $cryptService;
    protected $stNomeRel;
    protected $stExtensao;
    protected $environment;
    protected $birtStrategy;
    protected $reportMapping;
    protected $newCode;
    
    public function __construct (reportService $reportService, FornecedoresParaComprasExtrasService $service, $connection, $cryptService, $environment, $birtStrategy, $newCode) {
        parent::__construct($reportService);
        $this->connection    = $connection;
        $this->service       = $service;
        $this->cryptService  = $cryptService;
        $this->environment    = $environment;
        $this->birtStrategy = $birtStrategy;
        $this->newCode        = $newCode;
    }
    
    public function createListas(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        try{
           $result = $this->service->createListas($row);    
           $response->addDataSet(new DataSet("data", $result));
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function deleteListas(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        try{
           $result = $this->service->deleteListas($row); 
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function saveFornecedor(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $fornecedorExists = false;
        $fornecedor = $this->service->findFornecedor($row);
        
        if(!empty($fornecedor)){
            foreach ($fornecedor as $value) {
                if($value['CDFORNECED'] == $row['CDFORNECED']){
                    $fornecedorExists = true;
                    break;
                }
            }
        }
        
        if($fornecedorExists == true){
            $erro = new Error("Operação bloqueada! O fornecedor já está cadastrado!", 500);
            $response->setError($erro);
        }else{
            try{
                $this->service->insertFornecedor($row);    
            }catch(\Exception $e){
                $response->setError(new Error($e->getMessage(), 1));
            }
        }
    }  
    
    public function deleteFornecedor(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        try{
            $this->service->deleteFornecedor($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
    public function cadastramentoAutomatico(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        if(!is_array($row['CDMUNICIPIO'])){
            $getPais = explode('_', $row['CDMUNICIPIO']);
            $pais = $getPais[1];
            
            if($getPais[0] === "T"){
                $row['CDMUNICIPIO'] = $this->service->verifyData("todosMunicipios", "", $pais);
            }
        }
        if($row['NRINSJURFORN'] === "T"){
            $row['NRINSJURFORN'] = $this->service->verifyData("todosFornecedores");
        } 
        
        try{
            $this->service->cadastramentoAutomatico($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }  
    
    public function exportarFornecedores(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        if(!is_array($row["FORNDESTINO"])){
            $row["FORNDESTINO"] = $this->service->verifyData("fornecedoresExportados",$row["FORNORIGEM"]);
        }
        if(!is_array($row["MUNICIPIOATENDIDO"])){
            $row["MUNICIPIOATENDIDO"] = $this->service->verifyData("municipiosAtendidos",$row["FORNORIGEM"]);
        }
        try{
            $this->service->exportarFornecedores($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }
    
}