<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Modules\Cadastros\Services\MinimoFornecedorPorRegiaoService;

class Sup05300MinimoFornecedorPorRegiao extends \Zeedhi\Framework\Controller\Report {

    protected $connection;
    protected $qr2Strategy;
    
    public function __construct(ReportService $reportService, $connection, MinimoFornecedorPorRegiaoService $service, $qr2Strategy, $newCode, $environment, $birtStrategy) {
        parent::__construct($reportService);
        $this->connection   = $connection;
        $this->service      = $service;
        $this->qr2Strategy  =  $qr2Strategy;
        $this->newCode      = $newCode;
        $this->environment  = $environment;
        $this->birtStrategy = $birtStrategy;
    }
    
    public function SelectQuantidade (DTO\Request $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        
        $result = $this->service->selectQtd($row);
        $response->addDataSet(new DataSet("resp",[$result]));
    
    }
    
    public function RegiaoDelete(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
        $this->service->deleteRegiao($row);
    }
    
    public function RegiaoInsert(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
       
        if(self::verifyTableToInsert($row)){
            $this->service->insertRegiao($row);
        }else{
            $erro = new Error("Operação bloqueada! Região já cadastrada", 500);
            $response->setError($erro);
        }
        
    }
    
    public function verifyTableToInsert($row){
        $verifyTableToInsert = $this->service->getRegiao($row);
        if(!empty($verifyTableToInsert)){
            foreach ($verifyTableToInsert as $data) {
                if($data['CDREGIAO'] == $row['CDREGIAO']){
                    return false;
                }
            }
        }
        return true;
    }
    
    public function RegiaoUpdate(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        
       
        $this->service->updateRegiao($row);
        
    }
    public function FornecedorUpdate(DTO\Request\Row $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            if(!$row['QTMINAUTFOT'] || $row['QTMINAUTFOT'] <= 0 || !$row['SGUNIDADE']){    
                $this->verifyQtdRegiao($row);
                $this->service->updateFornecedor($row);
            }else{
                $this->service->updateFornecedor($row);
            }
        }catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function verifyQtdRegiao($row){

        $regioes = $this->service->getRegiao($row);
        $dadosFornecedor = $this->service->getDadosFornecedor($row)[0];
        for ($i = 0; $i < count($regioes); $i++) {
            if($regioes[$i]['QTMINFORNREG'] && $regioes[$i]['QTMINFORNREG'] > 0){
                if($dadosFornecedor['QTMINAUTFOT'] > 0){
                    throw new \Exception("Operação bloqueada! Não se pode apagar a unidade ou quantidade quando existe(m) região(ões) com quantidade cadastrada!");
                }
            }
        }
    }
        
        
    protected $reportMapping = array ();
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        $row['STRATEGY'] = $row['REPORT'] == 'SUP05300.QR2' ? 'QR2' : 'BIRT';
        
        $row['STRATEGY'] == 'BIRT' ? $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE'])) : $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        
        if($row['STRATEGY'] == 'BIRT'){
            if($row['CDFORNECED'] != 'T'){
                $nrlistaFor = $this->criarListaValores($row['CDFORNECED']);
                $row['CDFORNECED'] = "_NRLISTA=" . $nrlistaFor;
            }
            
            if($row['SGESTADO'] != 'T'){
                $nrlistaEst = $this->criarListaValores($row['SGESTADO']);
                $row['SGESTADO'] = "_NRLISTA=" . $nrlistaEst;
            }
            
            if($row['CDREGIAO'] != 'T'){
                $nrlistaReg = $this->criarListaValores($row['CDREGIAO']);
                $row['CDREGIAO'] = "_NRLISTA=" . $nrlistaReg;
            }
        }

        $this->stNomeRel = $this->getReportName($row);
        
        $this->reportMapping[$this->stNomeRel] =
            array (
            'strategy' => $row['STRATEGY'],
            'parameterMapping' =>
            array (
                'VALOR'      => 'P_VALOR',
                'QTD'        => 'P_QTDE',
                'CDFORNECED' => 'L_CDFORNECED',
                'CDPAIS'     => 'P_CDPAIS',
                'SGESTADO'   => 'L_SGESTADO',
                'CDREGIAO'   => 'L_CDREGIAO',
                'NRORG'      => 'P_NRORG'
            ),
        );
    }
    
    public function criarListaValores($lista){
        try{
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
            $valores = explode('_',$lista);
            
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
    }

    public function insertLista($nrlista, $cdlista) {
        try {
            $query = 'INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)';
            
            $params = array(
                'NRLISTA' => $nrlista,
                'CDLISTA' => $cdlista
            );
            
            $stmt = $this->connection->prepare($query);
            $stmt->execute($params);   
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
}